---
aliases:
  - ../eum.html
---

# EUM

The dfs items in MIKE IO are represented by the `ItemInfo` class. 
An ItemInfo consists of:

* name - a user-defined string 
* type - an [`EUMType`](`mikeio.EUMType`) 
* unit - an [`EUMUnit`](`mikeio.EUMUnit`)

The ItemInfo class has some sensible defaults, thus you can specify only a name or a type. If you don't specify a unit, the default unit for that type will be used.

```{python}
from mikeio import ItemInfo, EUMType, EUMUnit

item = ItemInfo("Viken", EUMType.Water_Level)
item
```

```{python}
ItemInfo(EUMType.Wind_speed)
```

```{python}
ItemInfo("Viken", EUMType.Water_Level, EUMUnit.feet)
```

Matching units for specific type:
```{python}
EUMType.Wind_speed.units
```

Default unit:
```{python}
EUMType.Precipitation_Rate.units[0]
```

```{python}
unit = EUMType.Precipitation_Rate.units[0]
unit
```

```{python}
type(unit)
```

`a [](`mikeio.EUMUnit)` is encoded as integers, which you can utilize in some MIKE applications.

```{python}
int(unit)
2004
```

## EUM type search

It is also possible to do a string based search, e.g. to find all EUM types containing the substring 'period':

```{python}
EUMType.search("period")
```

